/* Copyright 2015 The Chromium OS Authors. All rights reserved.
 * Use of this source code is governed by a BSD-style license that can be
 * found in the LICENSE file.
 */

#ifndef __CROS_EC_VEC_4_H

#define __CROS_EC_VEC_4_H

#include "math_util.h"

typedef float floatv4_t[4];
typedef fp_t fpv4_t[4];

#endif  /* __CROS_EC_VEC_4_H */
